@@ -3,5 +3,4 @@ module Sound.Osc.Fd (module M) where
 
 import Sound.Osc.Core as M
 import Sound.Osc.Transport.Fd as M
-import Sound.Osc.Transport.Fd.Udp as M
-import Sound.Osc.Transport.Fd.Tcp as M
+import Sound.Osc.Transport.Fd.Socket as M
