@@ -6,11 +6,12 @@ import Data.Word {- base -}
 
 import qualified Data.Time.Clock.System as Clock.System {- time >= 1.8 -}
 
-import Sound.Osc.Time {- hosc -}
+import qualified Sound.Osc.Time as Time {- hosc -}
 
--- | Get the system time, epoch start of 1970 UTC, leap-seconds ignored.
---   getSystemTime is typically much faster than getCurrentTime, however it is not available in Hugs.
-getSystemTimeAsNtpReal :: IO NtpReal
+{- | Get the system time, epoch start of 1970 UTC, leap-seconds ignored.
+  getSystemTime is typically much faster than getCurrentTime, however it is not available in Hugs.
+-}
+getSystemTimeAsNtpReal :: IO Time.NtpReal
 getSystemTimeAsNtpReal = do
   tm <- Clock.System.getSystemTime
   return (fromIntegral (Clock.System.systemSeconds tm) + (fromIntegral (Clock.System.systemNanoseconds tm) * 1.0e-9))
